@@ -1,5 +1,5 @@
 Clazz.declarePackage ("J.jvxl.data");
-Clazz.load (null, "J.jvxl.data.JvxlCoder", ["java.lang.Float", "JU.BS", "$.Lst", "$.P3", "$.PT", "$.SB", "J.api.Interface", "J.jvxl.data.VolumeData", "J.shapesurface.Isosurface", "JU.BSUtil", "$.C", "$.Escape", "$.Logger", "JV.Viewer"], function () {
+Clazz.load (null, "J.jvxl.data.JvxlCoder", ["java.lang.Float", "JU.BS", "$.Lst", "$.P3", "$.PT", "$.SB", "J.api.Interface", "J.jvxl.data.VolumeData", "JU.BSUtil", "$.C", "$.Escape", "$.Logger", "JV.Viewer"], function () {
 c$ = Clazz.declareType (J.jvxl.data, "JvxlCoder");
 c$.jvxlGetFile = Clazz.defineMethod (c$, "jvxlGetFile", 
 function (jvxlData, meshData, title, msg, includeHeader, nSurfaces, state, comment) {
@@ -167,9 +167,9 @@ if (jvxlData.meshColor != null) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  m
 if (jvxlData.colorScheme != null) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  colorScheme", jvxlData.colorScheme);
 if (jvxlData.rendering != null) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  rendering", jvxlData.rendering);
 if (jvxlData.thisSet != null) {
-var s = J.shapesurface.Isosurface.subsetString (jvxlData.thisSet);
-if (s.startsWith (" subset ")) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  subset", s.substring (8));
- else J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  set", s.substring (6));
+var s = J.jvxl.data.JvxlCoder.subsetString (jvxlData.thisSet);
+if (s.startsWith ("[")) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  subset", s);
+ else J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  set", s);
 }if (jvxlData.slabValue != -2147483648) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  slabValue", "" + jvxlData.slabValue);
 if (jvxlData.isSlabbable) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  slabbable", "true");
 if (jvxlData.nVertexColors > 0) J.jvxl.data.JvxlCoder.addAttrib (attribs, "\n  nVertexColors", "" + jvxlData.nVertexColors);
@@ -202,6 +202,16 @@ JU.XmlUtil.openTagAttr (info, "jvxlSurfaceInfo", attribs.toArray ( new Array (at
 JU.XmlUtil.closeTag (info, "jvxlSurfaceInfo");
 return info.toString ();
 }, "J.jvxl.data.JvxlData,~B");
+c$.subsetString = Clazz.defineMethod (c$, "subsetString", 
+ function (bs) {
+var n = bs.cardinality ();
+if (n > 1) {
+var a = "[ ";
+for (var ia = bs.nextSetBit (0); ia >= 0; ia = bs.nextSetBit (ia)) a += (++ia) + " ";
+
+return a + "]";
+}return "" + (bs.nextSetBit (0) + 1);
+}, "JU.BS");
 c$.addAttrib = Clazz.defineMethod (c$, "addAttrib", 
  function (attribs, name, value) {
 attribs.addLast ( Clazz.newArray (-1, [name, value]));
