@@ -665,10 +665,11 @@ var valid = this.getValidVertices (bs);
 if (valid != null) {
 info.put ("allVertices", info.get ("vertices"));
 info.put ("vertices", valid);
-if (this.vvs != null) {
+var values = info.get ("vertexValues");
+if (values != null) {
 var v = this.getValidValues (bs);
-info.put ("allValues", info.get ("values"));
-info.put ("values", v);
+info.put ("allValues", values);
+info.put ("vertexValues", v);
 }}}return info;
 }, "~B");
 Clazz.defineMethod (c$, "getValidValues", 
