@@ -1135,7 +1135,8 @@ var s = x.value;
 var isMinus = s.startsWith ("-");
 var f = (isMinus ? -1 : 1);
 if (isMinus) s = s.substring (1);
-switch ("xy yz xz x= y= z=".indexOf (s.substring (0, 2))) {
+var p4 = null;
+switch (s.length < 2 ? -1 : "xy yz xz x= y= z=".indexOf (s.substring (0, 2))) {
 case 0:
 return JU.P4.new4 (1, 1, 0, f);
 case 3:
@@ -1143,12 +1144,16 @@ return JU.P4.new4 (0, 1, 1, f);
 case 6:
 return JU.P4.new4 (1, 0, 1, f);
 case 9:
-return JU.P4.new4 (1, 0, 0, -f * JU.PT.parseFloat (s));
+p4 = JU.P4.new4 (1, 0, 0, -f * JU.PT.parseFloat (s.substring (2)));
+break;
 case 12:
-return JU.P4.new4 (0, 1, 0, -f * JU.PT.parseFloat (s));
+p4 = JU.P4.new4 (0, 1, 0, -f * JU.PT.parseFloat (s.substring (2)));
+break;
 case 15:
-return JU.P4.new4 (0, 0, 1, -f * JU.PT.parseFloat (s));
+p4 = JU.P4.new4 (0, 0, 1, -f * JU.PT.parseFloat (s.substring (2)));
+break;
 }
+if (p4 != null && !Float.isNaN (p4.w)) return p4;
 break;
 default:
 return null;
