@@ -70,15 +70,20 @@ this.setElement (3, 3, 1);
 }, "~B");
 Clazz.defineMethod (c$, "doFinalize", 
 function () {
-this.m03 /= 12;
-this.m13 /= 12;
-this.m23 /= 12;
+JS.SymmetryOperation.div12 (this);
 if (this.modDim > 0) {
 var a = this.rsvs.getArray ();
 for (var i = a.length - 1; --i >= 0; ) a[i][3 + this.modDim] /= 12;
 
 }this.isFinalized = true;
 });
+c$.div12 = Clazz.defineMethod (c$, "div12", 
+ function (op) {
+op.m03 /= 12;
+op.m13 /= 12;
+op.m23 /= 12;
+return op;
+}, "JU.M4");
 Clazz.defineMethod (c$, "getXyz", 
 function (normalized) {
 return (normalized && this.modDim == 0 || this.xyzOriginal == null ? this.xyz : this.xyzOriginal);
@@ -201,6 +206,12 @@ this.isFinalized = (offset == null);
 this.xyz = JS.SymmetryOperation.getXYZFromMatrix (this, true, false, false);
 return true;
 }, "~A,~B");
+c$.getMatrixFromXYZ = Clazz.defineMethod (c$, "getMatrixFromXYZ", 
+function (xyz) {
+var linearRotTrans =  Clazz.newFloatArray (16, 0);
+xyz = JS.SymmetryOperation.getMatrixFromString (null, xyz, linearRotTrans, false);
+return (xyz == null ? null : JS.SymmetryOperation.div12 (JU.M4.newA16 (linearRotTrans)));
+}, "~S");
 c$.getMatrixFromString = Clazz.defineMethod (c$, "getMatrixFromString", 
 function (op, xyz, linearRotTrans, allowScaling) {
 var isDenominator = false;
