@@ -60,7 +60,7 @@ return JU.Edge.EnumBondOrder.getNameFromCode (order);
 }, "~N");
 c$.getAtropismOrder = Clazz.defineMethod (c$, "getAtropismOrder", 
 function (nn, mm) {
-return JU.Edge.getAtropismOrder12 (((nn + 1) << 2) + mm + 1);
+return JU.Edge.getAtropismOrder12 (((nn) << 2) + mm);
 }, "~N,~N");
 c$.getAtropismOrder12 = Clazz.defineMethod (c$, "getAtropismOrder12", 
 function (nnmm) {
@@ -72,7 +72,7 @@ return (order >> (11)) & 0xF;
 }, "~N");
 c$.getAtropismNode = Clazz.defineMethod (c$, "getAtropismNode", 
 function (order, a1, isFirst) {
-var i1 = (order >> (11 + (isFirst ? 2 : 0))) & 3;
+var i1 = (order >> (11 + (isFirst ? 0 : 2))) & 3;
 return a1.getEdges ()[i1 - 1].getOtherNode (a1);
 }, "~N,JU.Node,~B");
 c$.isAtropism = Clazz.defineMethod (c$, "isAtropism", 
