@@ -63,7 +63,7 @@ var out = params.get ("outputChannel");
 var asBytes = (out == null && fileName == null);
 var closeChannel = (out == null && fileName != null);
 var releaseImage = (objImage == null);
-var image = (type.equals ("BINARY") || type.equals ("ZIPDATA") ? "" : rgbbuf != null ? rgbbuf : objImage != null ? objImage : this.vwr.getScreenImageBuffer (null, true));
+var image = (type.equals ("BINARY") || type.equals ("ZIPDATA") ? "" : rgbbuf != null ? rgbbuf : objImage != null ? objImage : this.vwr.getScreenImage ());
 var isOK = false;
 try {
 if (image == null) return errMsg = this.vwr.getErrorMessage ();
@@ -399,9 +399,10 @@ var saveWidth = 0;
 var saveHeight = 0;
 var quality = JV.OutputManager.getInt (params, "quality", -2147483648);
 var captureMode = params.get ("captureMode");
+var is2D = params.get ("is2D") === Boolean.TRUE;
 var localName = null;
 if (captureMode != null && !this.vwr.allowCapture ()) return "ERROR: Cannot capture on this platform.";
-var mustRender = (quality != -2147483648);
+var mustRender = (!is2D && quality != -2147483648);
 if (captureMode != null) {
 doCheck = false;
 mustRender = false;
@@ -506,11 +507,12 @@ break;
 }if (createImage) {
 if (localName != null) params.put ("fileName", localName);
 if (sret == null) sret = this.writeToOutputChannel (params);
+if (!is2D) {
 this.vwr.sm.createImage (sret, type, null, null, quality);
 if (captureMode != null) {
 if (captureMsg == null) captureMsg = sret;
  else captureMsg += " (" + params.get (params.containsKey ("captureByteCount") ? "captureByteCount" : "byteCount") + " bytes)";
-}}if (captureMsg != null) {
+}}}if (captureMsg != null) {
 this.vwr.showString (captureMsg, false);
 }}}} catch (er) {
 er.printStackTrace ();
